/*
 * Copyright(c)  2000  Rijkswaterstaat
 *                     Adviesdienst Verkeer en Vervoer
 * File: CRAPTAB.C
 *
 * Nummer kruispunt:        1
 * Regelprogramma vri:      Voorbeeld D: Wachtrijmeetpunt
 * datum:                   04-05-2000
 * gewijzigd:
 * versie:                  1
 */


#include "crtypes.h"
#include "crapcod.h"
#include "craptab.h"
#include "ccie_int.h"
#include "crapdef.h"


/*     BLOKKEN schema                                           */
struct BLOKKEN  BLOKKEN_tabel[] = {
/*     blok:    sg:     toewijzing:                             */
/*     BKl,     SGn,    PRIM + WSGR + ALT,                      */
       BK1,     SG02,   PRIM,
       BK2,     SG05,   PRIM,
       STOP};


/*     CONFLICT- en (garantie)ontruimingstijden matrix          */
struct CONFLICT  CONFLICT_tabel[] = {
/*                                    instellingen              */
/*                                    van de tijden:            */
/*     sg:       conflicterende sg:   GO_TIJD:  O_TIJD:         */
/*     SGn,      SGj,                 x.y,      x.y,            */
       SG02,     SG05,                2.0,      2.0,
       SG05,     SG02,                2.0,      2.0,
       STOP};


/*     SignaalGroep_TIJDEN tabel                                */
struct SG_TIJDEN  SG_TIJDEN_tabel[] = {
/*            instellingen van de tijden:                       */
/*     sg:    GG_TIJD:  VG_TIJD:  GGL_TIJD:  GL_TIJD:  GR_TIJD: */
/*     SGn,    x.y,      x.y,      x.y,       x.y,      x.y,    */
       SG02,   7.0,      7.0,      3.0,       3.0,      2.0,
       SG05,   7.0,      7.0,      3.0,       3.0,      2.0,
       STOP};


/*     MG_TIJDEN tabel                                          */
struct MG_TIJDEN  MG_TIJDEN_tabel[] = {
/*            instellingen (x.y of NG) van de tijden:           */
/*     sg:    MG_TIJD:  MG_TIJD1:  MG_TIJD2:  MG_TIJD3:         */
/*     SGn,    x.y,      x.y,       x.y,       x.y,             */
       SG02,  20.0,       NG,        NG,        NG,
       SG05,  20.0,       NG,        NG,        NG,
       STOP};


/*     Extra MG_TIJDEN tabel                                    */
struct E_MG_TIJDEN  E_MG_TIJDEN_tabel[] = {
/*            instellingen (x.y of NG) van de tijden:           */
/*     sg:    MG_TIJD4:  MG_TIJD5:  MG_TIJD6:                   */
/*     SGn;    x.y,       x.y,       x.y,                       */
       SG02,    NG,        NG,        NG,
       SG05,    NG,        NG,        NG,
       STOP};


/*     HiaatTIJDEN tabel                                        */
struct H_TIJDEN  H_TIJDEN_tabel[] = {
/*               instellingen (x.y of NG) van de tijden:        */
/*     sg:       H1e_TIJD:   H2e_TIJD:                          */
/*     SGn,       x.y,        x.y,                              */
       SG02,      2.0,         NG,
       SG05,      2.0,         NG,
       STOP};

/*     Extra-HiaatTIJDEN tabel                                  */
struct E_H_TIJDEN  E_H_TIJDEN_tabel[] = {
/*               instellingen (x.y of NG) van de tijden:        */
/*     sg:       E_H1e_TIJD:    E_H2e_TIJD:                     */
/*     SGn,       x.y,           x.y,                           */
       SG02,       NG,            NG,
       SG05,       NG,            NG,
       STOP};


/*     SignaalGroep-DETECTIE tabel                              */
struct SG_DETECTIE           SG_DETECTIE_tabel[] = {
/*     D():     type:        sg:     toewijzing:                */
/*     SGn_i,   DP (of DK),  SGn,    AVR + BS_H5p + H1e + H2e,  */
       SG02_1,  DP + DFA,    SG02,   AVR + BS_H5p,
       SG02_2,  DP + DFA,    SG02,   AVR + H1e,
       SG02_3,  DP + DFU,    SG02,   GEEN, /* wachtrij detector */
       SG02_4,  DP + DFU,    SG02,   GEEN, /* wachtrij detector */
       SG05_1,  DP + DFA,    SG05,   AVR + BS_H5p + H1e,
       STOP};


/*     TIJDEN tabel                                                   */
struct TIJDEN                 TIJDEN_tabel[] = {
/*     TIJD():                instelling:                             */
/*     SGn_i,                   x.y,                                  */

/*     invoer-parameters t.b.v. filemeetpunt                           */
       T_bezet_D02_3,        3.5,     /* als D langer bezet is -> wachtrij */
       T_bezet_D02_4,        3.5,     /* als D langer bezet is -> wachtrij */

       STOP};


/*     SCHAKELAAR tabel                                            */
struct SCHAKELAAR SCHAKELAAR_tabel[] = {
/*     SCH():                   instelling:                        */
/*     NAAM,                    AAN (of UIT),                      */
       SCH_wachtrij,            AAN,
       STOP};

Bool AFK_funct05 (void){
     return HF(HF_wachtrij)                 }
struct SG_OPTIE   AFK_OP_tabel[] = {
        SG05, AFK_funct05,
        STOP};

struct REGELING  REGELING_tabel[] = {
        1,
        STOP};

/*     SG gebonden optie: VAA_OP(SGn)                           */
struct SG_OPTIE  VAA_OP_tabel[] = { STOP};
struct SG_OPTIE  PPV_OP_tabel[] = { STOP};
struct WB WB_tabel[] = { STOP};
struct FICT_CONFLICT FICT_CONFLICT_tabel[] = { STOP};
struct SG_BS_H5t SG_BS_H5t_tabel[] = { STOP};
struct SG_BS_H5ac SG_BS_H5ac_tabel[] = { STOP};
struct SG_BS_H66 SG_BS_H66_tabel[] = { STOP};
struct SG_RGA   SG_RGA_tabel[] = { STOP};
struct FIETS_VOETG_R FIETS_VOETG_R_tabel[] = { STOP};
struct SG_MAH3 SG_MAH3_tabel[] = { STOP};
struct SG_PPAH SG_PPAH_tabel[] = { STOP};
struct SG_WSRH SG_WSRH_tabel[] = {   STOP};
struct KLOKKEN KLOKKEN_tabel[] = { STOP};
struct EPARMS EPARMS_tabel[] = { STOP};
struct BK_OPTIE   BO_OP_tabel[] = { STOP};
struct SG_OPTIE   MA_OP_tabel[] = { STOP};
struct SG_BK_OPTIE    PPP_OP_tabel[] = { STOP};
struct SG_OPTIE   MVG_OP_tabel[] = { STOP};
struct SG_OPTIE   TR_OP_tabel[] = { STOP};
struct SG_OPTIE   PPB_OP_tabel[] = { STOP};
struct SG_BK_OPTIE    PPA_OP_tabel[] = { STOP};
struct SG_BK_OPTIE    VNM_OP_tabel[] = { STOP};
struct SG_OPTIE   BL_OP_tabel[] = { STOP};
struct SG_OPTIE   RVG_OP_tabel[] = { STOP};
struct SG_OPTIE   VAG_OP_tabel[] = { STOP};
struct SG_OPTIE   VMG_OP_tabel[] = { STOP};
struct KOPPEL  KOPPEL_tabel[] = { STOP};

